@@ -50,7 +50,7 @@ from nipype.interfaces.io import add_traits
 from templateflow.api import templates as _get_template_list
 from ..utils.bids import _init_layout, relative_to_root
 from ..utils.images import set_consumables, unsafe_write_nifti_header_and_data
-from ..utils.misc import splitext as _splitext, _copy_any
+from ..utils.misc import splitext as _splitext, _copy_any, unlink
 
 regz = re.compile(r"\.gz$")
 _pybids_spec = loads(Path(_pkgres("niworkflows", "data/nipreps.json")).read_text())
@@ -669,7 +669,7 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                         new_header.set_data_dtype(data_dtype)
                 del nii
 
-            out_file.unlink(missing_ok=True)
+            unlink(out_file, missing_ok=True)
             if new_data is new_header is None:
                 _copy_any(orig_file, str(out_file))
             else:
@@ -710,11 +710,11 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                             legacy_metadata[key] = self._metadata.pop(key)
                     if legacy_metadata:
                         sidecar = out_file.parent / f"{_splitext(str(out_file))[0]}.json"
-                        sidecar.unlink(missing_ok=True)
+                        unlink(sidecar, missing_ok=True)
                         sidecar.write_text(dumps(legacy_metadata, sort_keys=True, indent=2))
                 # The future: the extension is the first . and everything after
                 sidecar = out_file.parent / f"{out_file.name.split('.', 1)[0]}.json"
-                sidecar.unlink(missing_ok=True)
+                unlink(sidecar, missing_ok=True)
                 sidecar.write_text(dumps(self._metadata, sort_keys=True, indent=2))
                 self._results["out_meta"] = str(sidecar)
         return runtime
